@@ -6,8 +6,15 @@
 #' oa_entities()
 oa_entities <- function() {
   c(
-    "works", "authors", "institutions", "concepts", "keywords",
-    "funders", "sources", "publishers", "topics"
+    "works",
+    "authors",
+    "institutions",
+    "concepts",
+    "keywords",
+    "funders",
+    "sources",
+    "publishers",
+    "topics"
   )
 }
 
@@ -68,31 +75,41 @@ oa_entities <- function() {
 #'   verbose = TRUE
 #' )
 #' }
-oa_fetch <- function(entity = if (is.null(identifier)) NULL else id_type(shorten_oaid(identifier[[1]])),
-                     identifier = NULL,
-                     ...,
-                     options = NULL,
-                     search = NULL,
-                     group_by = NULL,
-                     output = c("tibble", "dataframe", "list", "raw"),
-                     abstract = TRUE,
-                     endpoint = "https://api.openalex.org",
-                     per_page = 200,
-                     paging = NULL,
-                     pages = NULL,
-                     count_only = FALSE,
-                     mailto = oa_email(),
-                     api_key = oa_apikey(),
-                     verbose = FALSE) {
+oa_fetch <- function(
+  entity = if (is.null(identifier)) {
+    NULL
+  } else {
+    id_type(shorten_oaid(identifier[[1]]))
+  },
+  identifier = NULL,
+  ...,
+  options = NULL,
+  search = NULL,
+  group_by = NULL,
+  output = c("tibble", "dataframe", "list", "raw"),
+  abstract = TRUE,
+  endpoint = "https://api.openalex.org",
+  per_page = 200,
+  paging = NULL,
+  pages = NULL,
+  count_only = FALSE,
+  mailto = oa_email(),
+  api_key = oa_apikey(),
+  verbose = FALSE
+) {
   output <- match.arg(output)
   entity <- match.arg(entity, oa_entities())
 
-  if (output == "dataframe") output <- "tibble"
+  if (output == "dataframe") {
+    output <- "tibble"
+  }
   filter <- list(...)
 
   # if multiple identifiers are provided, use openalex or doi as a filter attribute
   multiple_id <- length(identifier) > 1
-  if (multiple_id) filter <- c(filter, list(openalex = identifier))
+  if (multiple_id) {
+    filter <- c(filter, list(openalex = identifier))
+  }
 
   # overcome OA limitation of combining 50 values (OR) for a filter at a time
   # https://docs.openalex.org/how-to-use-the-api/get-lists-of-entities/filter-entity-lists#addition-or
@@ -146,23 +163,31 @@ oa_fetch <- function(entity = if (is.null(identifier)) NULL else id_type(shorten
     )
   }
 
-  if (length(final_res[[1]]) == 0) { # || is.null(final_res[[1]][[1]]$id)
+  if (length(final_res[[1]]) == 0) {
+    # || is.null(final_res[[1]][[1]]$id)
     return(NULL)
   }
   final_res <- unlist(final_res, recursive = FALSE)
 
-  if (output %in% c("list", "raw")) {
+  if (output %in% c("list", "raw") || count_only) {
     return(final_res)
   }
 
   # Flatten out the initial chunking of 50 at a time
   final_res <- list(final_res)
-  do.call(rbind, lapply(
-    final_res, oa2df,
-    entity = entity, options = options, abstract = abstract,
-    count_only = count_only, group_by = group_by,
-    verbose = verbose
-  ))
+  do.call(
+    rbind,
+    lapply(
+      final_res,
+      oa2df,
+      entity = entity,
+      options = options,
+      abstract = abstract,
+      count_only = count_only,
+      group_by = group_by,
+      verbose = verbose
+    )
+  )
 }
 
 #' Get bibliographic records from OpenAlex database
@@ -304,15 +329,17 @@ oa_fetch <- function(entity = if (is.null(identifier)) NULL else id_type(shorten
 #' }
 #' @export
 #'
-oa_request <- function(query_url,
-                       per_page = 200,
-                       paging = "cursor",
-                       pages = NULL,
-                       count_only = FALSE,
-                       mailto = oa_email(),
-                       api_key = oa_apikey(),
-                       parse = TRUE,
-                       verbose = FALSE) {
+oa_request <- function(
+  query_url,
+  per_page = 200,
+  paging = "cursor",
+  pages = NULL,
+  count_only = FALSE,
+  mailto = oa_email(),
+  api_key = oa_apikey(),
+  parse = TRUE,
+  verbose = FALSE
+) {
   # https://httr.r-lib.org/articles/api-packages.html#set-a-user-agent
   ua <- httr::user_agent("https://github.com/ropensci/openalexR/")
 
@@ -335,7 +362,13 @@ oa_request <- function(query_url,
   }
 
   # first, download info about n. of items returned by the query
-  res <- api_request(query_url, ua, query = query_ls, api_key = api_key, parse = FALSE)
+  res <- api_request(
+    query_url,
+    ua,
+    query = query_ls,
+    api_key = api_key,
+    parse = FALSE
+  )
   res_parsed <- jsonlite::fromJSON(res, simplifyVector = FALSE)
   res_meta <- res_parsed$meta
   if (parse) {
@@ -364,9 +397,13 @@ oa_request <- function(query_url,
     res <- NULL
     i <- 1
     next_page <- get_next_page("cursor", i, res)
-    if (verbose) cat("\nDownloading groups...\n|")
+    if (verbose) {
+      cat("\nDownloading groups...\n|")
+    }
     while (!is.null(next_page)) {
-      if (verbose) cat("=")
+      if (verbose) {
+        cat("=")
+      }
       Sys.sleep(1 / 10)
       query_ls[[paging]] <- next_page
       res <- api_request(query_url, ua, query = query_ls)
@@ -389,7 +426,10 @@ oa_request <- function(query_url,
   } else {
     pages <- pages[pages <= n_pages]
     n_pages <- length(pages)
-    n_items <- min(n_items - per_page * (utils::tail(pages, 1) - n_pages), per_page * n_pages)
+    n_items <- min(
+      n_items - per_page * (utils::tail(pages, 1) - n_pages),
+      per_page * n_pages
+    )
     message("Using basic paging...")
     paging <- "page"
   }
@@ -403,8 +443,13 @@ oa_request <- function(query_url,
 
   if (verbose) {
     message(
-      "Getting ", n_pages, pg_plural, " of results",
-      " with a total of ", n_items, " records..."
+      "Getting ",
+      n_pages,
+      pg_plural,
+      " of results",
+      " with a total of ",
+      n_items,
+      " records..."
     )
     pb <- oa_progress(n = n_pages, text = "OpenAlex downloading")
   }
@@ -413,7 +458,9 @@ oa_request <- function(query_url,
   data <- vector("list", length = n_pages)
   res <- NULL
   for (i in pages) {
-    if (verbose) pb$tick()
+    if (verbose) {
+      pb$tick()
+    }
     Sys.sleep(1 / 10)
     next_page <- get_next_page(paging, i, res)
     query_ls[[paging]] <- next_page
@@ -429,7 +476,9 @@ oa_request <- function(query_url,
   data <- unlist(data, recursive = FALSE)
 
   # `output = "raw"` early exit
-  if (!parse) return(data)
+  if (!parse) {
+    return(data)
+  }
 
   if (grepl("filter", query_url) && grepl("works", query_url)) {
     truncated <- unlist(truncated_authors(data))
@@ -456,7 +505,7 @@ oa_request <- function(query_url,
 truncated_authors <- function(list_result) {
   lapply(
     list_result,
-    function(x){
+    function(x) {
       trunc <- x$is_authors_truncated
       if (!is.null(trunc) && trunc) x$id else NULL
     }
@@ -464,7 +513,8 @@ truncated_authors <- function(list_result) {
 }
 
 get_next_page <- function(paging, i, res = NULL) {
-  if (paging == "page") { # basic paging
+  if (paging == "page") {
+    # basic paging
     return(i)
   }
   # cursor paging
@@ -602,16 +652,18 @@ get_next_page <- function(paging, i, res = NULL) {
 #' @export
 #'
 
-oa_query <- function(filter = NULL,
-                     multiple_id = FALSE,
-                     identifier = NULL,
-                     entity = if (is.null(identifier)) NULL else id_type(identifier[[1]]),
-                     options = NULL,
-                     search = NULL,
-                     group_by = NULL,
-                     endpoint = "https://api.openalex.org",
-                     verbose = FALSE,
-                     ...) {
+oa_query <- function(
+  filter = NULL,
+  multiple_id = FALSE,
+  identifier = NULL,
+  entity = if (is.null(identifier)) NULL else id_type(identifier[[1]]),
+  options = NULL,
+  search = NULL,
+  group_by = NULL,
+  endpoint = "https://api.openalex.org",
+  verbose = FALSE,
+  ...
+) {
   entity <- match.arg(entity, oa_entities())
   filter <- c(filter, list(...))
 
@@ -640,11 +692,15 @@ oa_query <- function(filter = NULL,
   }
 
   if (is.null(identifier) || multiple_id) {
-    if (length(filter) == 0 &&
-      is.null(search) &&
-      is.null(group_by) &&
-      is.null(options$sample)) {
-      message("Identifier is missing, please specify filter or search argument.")
+    if (
+      length(filter) == 0 &&
+        is.null(search) &&
+        is.null(group_by) &&
+        is.null(options$sample)
+    ) {
+      message(
+        "Identifier is missing, please specify filter or search argument."
+      )
       return()
     }
 
@@ -676,7 +732,9 @@ oa_query <- function(filter = NULL,
     url_display <- paste0(substr(query_url, 1, oa_print()), query_url_more)
   }
 
-  if (verbose) message("Requesting url: ", url_display)
+  if (verbose) {
+    message("Requesting url: ", url_display)
+  }
 
   query_url
 }
@@ -694,28 +752,38 @@ oa_query <- function(filter = NULL,
 #'
 #' @examples
 #' oa_random()
-oa_random <- function(entity = oa_entities(),
-                      output = c("tibble", "dataframe", "list"),
-                      endpoint = "https://api.openalex.org") {
+oa_random <- function(
+  entity = oa_entities(),
+  output = c("tibble", "dataframe", "list"),
+  endpoint = "https://api.openalex.org"
+) {
   output <- match.arg(output)
   entity <- match.arg(entity, oa_entities())
-  if (output == "dataframe") output <- "tibble"
+  if (output == "dataframe") {
+    output <- "tibble"
+  }
 
   query_url <- paste(endpoint, entity, "random", sep = "/")
   res <- oa_request(query_url)
 
-  final_res <- switch(output,
-    list = res,
-    tibble = oa2df(res,
-      entity = entity
-    )
-  )
+  final_res <- switch(output, list = res, tibble = oa2df(res, entity = entity))
 
   final_res
 }
 
-api_request <- function(query_url, ua, query, api_key = oa_apikey(), parse = TRUE) {
-  res <- httr::GET(query_url, ua, query = query, httr::add_headers(api_key = api_key))
+api_request <- function(
+  query_url,
+  ua,
+  query,
+  api_key = oa_apikey(),
+  parse = TRUE
+) {
+  res <- httr::GET(
+    query_url,
+    ua,
+    query = query,
+    httr::add_headers(api_key = api_key)
+  )
 
   empty_res <- if (parse) list() else "{}"
 
@@ -734,7 +802,10 @@ api_request <- function(query_url, ua, query, api_key = oa_apikey(), parse = TRU
   }
 
   if (httr::status_code(res) == 503) {
-    mssg <- regmatches(m, regexpr("(?<=<title>).*?(?=<\\/title>)", m, perl = TRUE))
+    mssg <- regmatches(
+      m,
+      regexpr("(?<=<title>).*?(?=<\\/title>)", m, perl = TRUE)
+    )
     message(mssg, ". Please try setting `per_page = 25` in your function call!")
     return(empty_res)
   }
