@@ -2,7 +2,7 @@ test_that("oa_snowball works", {
   skip_on_cran()
 
   work_ids <- c("W3045921891", "W3046863325")
-  Sys.sleep(1/10)
+  Sys.sleep(1 / 10)
   multi_works <- oa_snowball(identifier = work_ids) # no cited papers
   multi_nodes <- multi_works$nodes
   flat_snow <- oa2df(multi_works, "snowball")
@@ -16,8 +16,12 @@ test_that("oa_snowball works", {
   expect_equal(ncol(flat_snow), ncol(multi_nodes) + 6)
 
   c(
-    "cited_by", "citing", "connection",
-    "forward_count", "backward_count", "connection_count"
+    "cited_by",
+    "citing",
+    "connection",
+    "forward_count",
+    "backward_count",
+    "connection_count"
   ) |>
     `%in%`(names(flat_snow)) |>
     all() |>
@@ -29,7 +33,7 @@ test_that("oa_snowball works", {
 test_that("oa_snowball works for recent articles with no citations yet", {
   skip_on_cran()
 
-  Sys.sleep(1/10)
+  Sys.sleep(1 / 10)
   snowball_docs <- oa_snowball(
     identifier = c("W2033458484")
   )
@@ -43,7 +47,7 @@ test_that("oa_snowball works for DOIs", {
     "10.1145/3383583.3398584",
     "https://doi.org/10.1038/s41586-022-05258-z"
   )
-  Sys.sleep(1/10)
+  Sys.sleep(1 / 10)
   snowball_doi <- oa_snowball(doi = work_dois)
   doi_nodes <- snowball_doi$nodes
   dois_in <- doi_nodes$doi[doi_nodes$oa_input]
@@ -57,7 +61,7 @@ test_that("oa_snowball works for author orcids", {
   skip_on_cran()
 
   orcids <- c("0000-0003-3737-6565", "0000-0002-8517-9411")
-  Sys.sleep(1/10)
+  Sys.sleep(1 / 10)
   # find publications by these two authors this year
   snowball_orcid <- oa_snowball(
     author.orcid = orcids,
